# Copyright (C) 2025 Cardiff University
#
# This file is part of GWDataFind.
#
# GWDataFind is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# GWDataFind is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with GWDataFind.  If not, see <http://www.gnu.org/licenses/>.

"""GWDataFind documentation configuration file."""

from datetime import (
    datetime,
    timezone,
)

import sphinx_github_style

import gwdatafind

# -- metadata

project = "gwdatafind"
copyright = f"{datetime.now(tz=timezone.utc).date().year}, Cardiff University"
author = "Duncan Macleod"
release = gwdatafind.__version__
version = release.split("+", 1)[0]

# -- config

source_suffix = ".rst"
master_doc = "index"

default_role = "obj"

# -- theme

html_theme = "furo"
html_title = f"{project} {version}"

html_theme_options = {
    "footer_icons": [
        {
            "name": "GitLab",
            "url": "https://git.ligo.org/computing/gwdatafind/client",
            "class": "fa-brands fa-gitlab",
        },
    ],
}

# need fontawesome for the gitlab icon in the footer
html_css_files = [
    "https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.1.2/css/fontawesome.min.css",
    "https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.1.2/css/solid.min.css",
    "https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.1.2/css/brands.min.css",
]

pygments_dark_style = "monokai"

# -- extensions

extensions = [
    "sphinx.ext.intersphinx",
    "sphinx.ext.napoleon",
    "sphinx.ext.linkcode",
    "sphinxarg.ext",
    "sphinx_automodapi.automodapi",
    "sphinx_copybutton",
    "sphinxarg.ext",
]

# automodapi
automodapi_inherited_members = False

# copybutton
copybutton_prompt_text = " |".join((  # noqa: FLY002
    ">>>",
    r"\.\.\.",
    r"\$"
    r"In \[\d*\]:",
    r" {2,5}\.\.\.:",
    " {5,8}: ",
))
copybutton_prompt_is_regexp = True
copybutton_line_continuation_character = "\\"

# intersphinx
intersphinx_mapping = {key: (value, None) for key, value in {
    "igwn-auth-utils": "https://igwn-auth-utils.readthedocs.io/en/stable/",
    "igwn-segments": "https://igwn-segments.readthedocs.io/en/stable/",
    "python": "https://docs.python.org/",
    "requests": "https://requests.readthedocs.io/en/stable/",
    "scitokens": "https://scitokens.readthedocs.io/en/stable/",
}.items()}

# linkcode
linkcode_url = sphinx_github_style.get_linkcode_url(
    blob=sphinx_github_style.get_linkcode_revision("head"),
    url="https://git.ligo.org/computing/gwdatafind/client",
)
linkcode_resolve = sphinx_github_style.get_linkcode_resolve(linkcode_url)

# napoleon
napoleon_use_rtype = False
